LocationHint

Enum LocationHint 

#[non_exhaustive]
pub enum LocationHint { Afr, Apac, EEur, ENam, Me, Oc, Sam, WEur, WNam, }
Durable Objects location hint.

These are the supported regions for Durable Objects location hints. Note: Location hints are best-effort and not guaranteed.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Afr

Africa



Apac

Asia-Pacific



EEur

Eastern Europe



ENam

Eastern North America



Me

Middle East



Oc

Oceania



Sam

South America



WEur

Western Europe



WNam

Western North America

Implementations

Source

impl LocationHint

pub const ALL: &'static [LocationHint]

Returns all location hints.

pub const fn as_str(&self) -> &'static str

Returns the location hint code as used in the Cloudflare API.

pub const fn name(&self) -> &'static str

Returns the human-readable name of the location.

pub fn parse(s: &str) -> Option<Self>

Parse a location hint from its string code.